#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for latex-xft-fonts
#---( These fonts are required to display math symbols in LyX compiled with Qt-frontend.
#---( Source URL: ftp://ftp.lyx.org/pub/lyx/contrib/latex-xft-fonts-0.1.tar.gz 
#---( Build script by R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Saturday, October 07, 2006.


#------------------( Set Package Name & Version )

soft='latex-xft-fonts'
softversion='0.1'
packageversion='1rsa'
arch='noarch'

#------------------( Set Build Location Variables )

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

#------------------( Clean, prepare the work area and extract the source code )

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships )

chown -R root:root .


#------------------( Move Documentation and TTF Font Files To Correct Location )

mkdir -p $dest/usr/doc/$soft-$softversion
cd $src
cp -a \
  Makefile README latex-xft-fonts.spec \
  $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/X11/lib/fonts/TTF
cp $src/*.ttf $dest/usr/X11/lib/fonts/TTF


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
               |-----handy-ruler------------------------------------------------------|
latex-xft-fonts: LaTeX Xft Fonts (Xft-compatible versions of some LaTeX fonts)
latex-xft-fonts: 
latex-xft-fonts: Some xft-compatible versions of LaTeX fonts for use with visual math
latex-xft-fonts: symbol display in LyX. It is useful primarily for the LyX Qt frontend.
latex-xft-fonts: 
latex-xft-fonts:
latex-xft-fonts:
latex-xft-fonts:
latex-xft-fonts:
latex-xft-fonts:
latex-xft-fonts: Packaged by R S Ananda Murthy on a Slackware-11 system.
EOF

#------------------( Create the doinst.sh file )

mkdir -p $dest/install
cat <<EOF > $dest/install/doinst.sh
cd /usr/X11/lib/fonts/TTF
cp fonts.dir fonts.dir.bak
cp fonts.scale fonts.scale.bak
mkfontscale
mkfontdir
fc-cache
xset fp rehash
EOF


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest

#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5